@@ -29,11 +29,9 @@
 #include <QLineEdit>
 #include <QPushButton>
 #include <QTableView>
-#include <QVBoxLayout>
 
 #include <KActionCollection>
 #include <KConfigGroup>
-#include <KIconLoader>
 #include <KLocalizedString>
 
 using namespace KgpgCore;
@@ -57,7 +55,7 @@ KgpgSelectPublicKeyDlg::KgpgSelectPublicKeyDlg(QWidget *parent, KGpgItemModel *m
     m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     m_detailsButton = new QPushButton(this);
     m_detailsButton->setText(i18n("&Options") + QStringLiteral(" >>"));
-    m_detailsButton->setIcon(QIcon::fromTheme(QStringLiteral("help-about")).pixmap(IconSize(KIconLoader::Toolbar)));
+    m_detailsButton->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
     connect(m_detailsButton, &QPushButton::clicked, this, &KgpgSelectPublicKeyDlg::toggleDetails);
     buttonBox->addButton(m_detailsButton, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &KgpgSelectPublicKeyDlg::accept);
